@@ -1,11 +1,11 @@
+from workflow.figure_to_numpy import figure_to_numpy
+from workflow.train_test_split import train_test_split
+from workflow.temporary_numpy_seed import temporary_numpy_seed
+
 from workflow import functional
 from workflow import ignite
 from workflow import torch
 
-from .figure_to_numpy import figure_to_numpy
-from .split_new_data import split_new_data
-from .temporary_numpy_seed import temporary_numpy_seed
-
 from pkg_resources import get_distribution, DistributionNotFound
 try:
     __version__ = get_distribution('ml-workflow').version
