@@ -100,7 +100,7 @@ class Datastream:
                 samplers_and_ns,
                 Dataset.create_to_concat_mapping(datasets),
             ),
-            length=max(map(len, datasets)),
+            length=max(map(len, datasets)) * len(datasets),
         )
 
         return Datastream(
@@ -118,8 +118,8 @@ class Datastream:
 def test_datastream():
 
     datastream = Datastream.merge([
-        Datastream(Dataset.from_indexable(list('abc'))),
-        Datastream(Dataset.from_indexable(list('def'))),
+        Datastream(Dataset.from_subscriptable(list('abc'))),
+        Datastream(Dataset.from_subscriptable(list('def'))),
     ])
 
     it = iter(datastream.sampler)
